@@ -7,6 +7,7 @@ import json
 import logging
 import tempfile
 import time
+from datetime import datetime, timedelta
 
 import OpenSSL.crypto
 import paho.mqtt.client as mqtt
@@ -87,6 +88,8 @@ class WorxCloud:
         self.serial_number = None
         self.status = None
         self.status_description = None
+        self.torque = None
+        self.torque_capable = False
         self.updated = None
         self.work_time = 0
         self.yaw = 0
@@ -255,6 +258,11 @@ class WorxCloud:
             self.rain_delay = data["cfg"]["rd"]
             self.serial = data["cfg"]["sn"]
 
+            # Fetch wheel torque
+            if "tq" in data["cfg"]:
+                self.torque_capable = True
+                self.torque = data["cfg"]["tq"]
+
             # Fetch zone information
             if "mz" in data["cfg"]:
                 self.zone = data["cfg"]["mz"]
@@ -284,6 +292,30 @@ class WorxCloud:
                         data["cfg"]["sc"]["d"][day][2]
                     )
 
+                    time_start = datetime.strptime(
+                        self.schedules[TYPE_MAP[sch_type]][DAY_MAP[day]]["start"],
+                        "%H:%M",
+                    )
+
+                    if isinstance(
+                        self.schedules[TYPE_MAP[sch_type]][DAY_MAP[day]]["duration"],
+                        type(None),
+                    ):
+                        self.schedules[TYPE_MAP[sch_type]][DAY_MAP[day]][
+                            "duration"
+                        ] = "0"
+
+                    duration = int(
+                        self.schedules[TYPE_MAP[sch_type]][DAY_MAP[day]]["duration"]
+                    )
+
+                    duration = duration * (1 + (int(self.schedule_variation) / 100))
+                    end_time = time_start + timedelta(minutes=duration)
+
+                    self.schedules[TYPE_MAP[sch_type]][DAY_MAP[day]][
+                        "end"
+                    ] = end_time.time().strftime("%H:%M")
+
             # Fetch secondary schedule
             if "dd" in data["cfg"]["sc"]:
                 sch_type = ScheduleType.SECONDARY
@@ -301,6 +333,22 @@ class WorxCloud:
                         data["cfg"]["sc"]["dd"][day][2]
                     )
 
+                    time_start = datetime.strptime(
+                        data["cfg"]["sc"]["dd"][day][0],
+                        "%H:%M",
+                    )
+
+                    duration = int(
+                        self.schedules[TYPE_MAP[sch_type]][DAY_MAP[day]]["duration"]
+                    )
+
+                    duration = duration * (1 + (int(self.schedule_variation) / 100))
+                    end_time = time_start + timedelta(minutes=duration)
+
+                    self.schedules[TYPE_MAP[sch_type]][DAY_MAP[day]][
+                        "end"
+                    ] = end_time.time().strftime("%H:%M")
+
         self.wait = False
 
     def _on_connect(
